@@ -28,27 +28,23 @@ namespace Sass {
           dynamic_cast<Supports_Operator*>(cond);
   }
 
-  std::string & str_ltrim(std::string & str)
+  void str_rtrim(std::string& s, const std::string& delimiters = " \f\n\r\t\v" )
   {
-    auto it2 =  std::find_if( str.begin() , str.end() , [](char ch){ return !std::isspace<char>(ch , std::locale::classic() ) ; } );
-    str.erase( str.begin() , it2);
-    return str;
+     s.erase( s.find_last_not_of( delimiters ) + 1 );
   }
 
-  std::string & str_rtrim(std::string & str)
+  void str_ltrim(std::string& s,  const std::string& delimiters = " \f\n\r\t\v" )
   {
-    auto it1 =  std::find_if( str.rbegin() , str.rend() , [](char ch){ return !std::isspace<char>(ch , std::locale::classic() ) ; } );
-    str.erase( it1.base() , str.end() );
-    return str;
+     s.erase( 0, s.find_first_not_of( delimiters ) );
   }
 
   void String_Constant::rtrim()
   {
-    value_ = str_rtrim(value_);
+    str_rtrim(value_);
   }
   void String_Constant::ltrim()
   {
-    value_ = str_ltrim(value_);
+    str_ltrim(value_);
   }
   void String_Constant::trim()
   {
@@ -82,7 +78,7 @@ namespace Sass {
 
   void Arguments::set_delayed(bool delayed)
   {
-    for (Argument* arg : elements()) {
+    for (auto __arg = elements().begin(); __arg != elements().end(); ++__arg) { Argument* arg = *(__arg);
       if (arg) arg->set_delayed(delayed);
     }
     is_delayed(delayed);
@@ -151,7 +147,7 @@ namespace Sass {
 
   bool SimpleSequence_Selector::has_parent_ref()
   {
-    for (Simple_Selector* s : *this) {
+    for (auto __s = elements().begin(); __s != elements().end(); ++__s) { Simple_Selector* s = *(__s);
       if (s && s->has_parent_ref()) return true;
     }
     return false;
@@ -508,12 +504,12 @@ namespace Sass {
   }
 
   SimpleSequence_Selector* Id_Selector::unify_with(SimpleSequence_Selector* rhs, Context& ctx)
-  {
-    for (size_t i = 0, L = rhs->length(); i < L; ++i)
     {
-      Simple_Selector* rhs_i = (*rhs)[i];
+      for (size_t i = 0, L = rhs->length(); i < L; ++i)
+      {
+        Simple_Selector* rhs_i = (*rhs)[i];
       if (typeid(*rhs_i) == typeid(Id_Selector) && static_cast<Id_Selector*>(rhs_i)->name() != name()) {
-        return 0;
+          return 0;
       }
     }
     rhs->has_line_break(has_line_break());
@@ -675,7 +671,7 @@ namespace Sass {
 
   bool SimpleSequence_Selector::is_superselector_of(CommaSequence_Selector* rhs, std::string wrapped)
   {
-    for (Sequence_Selector* item : rhs->elements()) {
+    for (auto __item = rhs->elements().begin(); __item != rhs->elements().end(); ++__item) { Sequence_Selector* item = *(__item);
       if (is_superselector_of(item, wrapped)) return true;
     }
     return false;
@@ -790,8 +786,8 @@ namespace Sass {
       rset.insert(r->to_string());
     }
 
-    //for (auto l : lset) { cerr << "l: " << l << endl; }
-    //for (auto r : rset) { cerr << "r: " << r << endl; }
+    //for (auto __l = lset.begin(); __l != lset.end(); ++__l) { auto l = *(__l); cerr << "l: " << l << endl; }
+    //for (auto __r = rset.begin(); __r != rset.end(); ++__r) { auto r = *(__r); cerr << "r: " << r << endl; }
 
     if (lset.empty()) return true;
     // return true if rset contains all the elements of lset
@@ -1093,7 +1089,7 @@ namespace Sass {
 
   CommaSequence_Selector* CommaSequence_Selector::resolve_parent_refs(Context& ctx, CommaSequence_Selector* ps, bool implicit_parent)
   {
-    if (!this->has_parent_ref()/* && !implicit_parent*/) return this;
+    if (!this->has_parent_ref()) return this;
     CommaSequence_Selector* ss = SASS_MEMORY_NEW(ctx.mem, CommaSequence_Selector, pstate());
     for (size_t pi = 0, pL = ps->length(); pi < pL; ++pi) {
       CommaSequence_Selector* list = SASS_MEMORY_NEW(ctx.mem, CommaSequence_Selector, pstate());
@@ -1110,7 +1106,7 @@ namespace Sass {
     Sequence_Selector* tail = this->tail();
     SimpleSequence_Selector* head = this->head();
 
-    // first resolve_parent_refs the tail (which may return an expanded list)
+    // first parentize the tail (which may return an expanded list)
     CommaSequence_Selector* tails = tail ? tail->resolve_parent_refs(ctx, parents, implicit_parent) : 0;
 
     if (head && head->length() > 0) {
@@ -1189,7 +1185,7 @@ namespace Sass {
         retval = this->tails(ctx, tails);
       }
 
-      for (Simple_Selector* ss : *head) {
+      for (auto __ss = head->elements().begin(); __ss != head->elements().end(); ++__ss) { Simple_Selector* ss = *(__ss);
         if (Wrapped_Selector* ws = dynamic_cast<Wrapped_Selector*>(ss)) {
           if (CommaSequence_Selector* sl = dynamic_cast<CommaSequence_Selector*>(ws->selector())) {
             if (parents) ws->selector(sl->resolve_parent_refs(ctx, parents, implicit_parent));
@@ -1358,7 +1354,7 @@ namespace Sass {
   }
 
   /* not used anymore - remove?
-  Placeholder_Selector* Selector::find_placeholder()
+  Selector_Placeholder* Selector::find_placeholder()
   {
     return 0;
   }*/
@@ -1390,7 +1386,7 @@ namespace Sass {
 
   bool CommaSequence_Selector::has_parent_ref()
   {
-    for (Sequence_Selector* s : *this) {
+    for (auto __s = elements().begin(); __s != elements().end(); ++__s) { Sequence_Selector* s = *(__s);
       if (s && s->has_parent_ref()) return true;
     }
     return false;
@@ -1470,7 +1466,7 @@ namespace Sass {
       }
     }
 
-    // Creates the final CommaSequence_Selector by combining all the complex selectors
+    // Creates the final Selector_List by combining all the complex selectors
     CommaSequence_Selector* final_result = SASS_MEMORY_NEW(ctx.mem, CommaSequence_Selector, pstate());
     for (auto itr = unified_complex_selectors.begin(); itr != unified_complex_selectors.end(); ++itr) {
       *final_result << *itr;
@@ -1482,7 +1478,7 @@ namespace Sass {
   {
 
     CommaSequence_Selector* extender = this;
-    for (auto complex_sel : extendee->elements()) {
+    for (auto __complex_sel = extendee->elements().begin(); __complex_sel != extendee->elements().end(); ++__complex_sel) { auto complex_sel = *(__complex_sel);
       Sequence_Selector* c = complex_sel;
 
 
@@ -1555,7 +1551,7 @@ namespace Sass {
   {
     Argument* arg = 0;
     if (this->has_rest_argument()) {
-      for (auto a : this->elements()) {
+      for (auto __a = this->elements().begin(); __a != this->elements().end(); ++__a) { auto a = *(__a);
         if (a->is_rest_argument()) {
           arg = a;
           break;
@@ -1570,7 +1566,7 @@ namespace Sass {
   {
     Argument* arg = 0;
     if (this->has_keyword_argument()) {
-      for (auto a : this->elements()) {
+      for (auto __a = this->elements().begin(); __a != this->elements().end(); ++__a) { auto a = *(__a);
         if (a->is_keyword_argument()) {
           arg = a;
           break;
@@ -1738,8 +1734,7 @@ namespace Sass {
     denominator_units_.clear();
 
     // build them by iterating over the exponents
-    for (auto exp : exponents)
-    {
+    for (auto __exp = exponents.begin(); __exp != exponents.end(); ++__exp) { auto exp = *(__exp);
       // maybe there is more effecient way to push
       // the same item multiple times to a vector?
       for(size_t i = 0, S = abs(exp.second); i < S; ++i)
@@ -1950,8 +1945,7 @@ namespace Sass {
     denominator_units_.clear();
 
     // build them by iterating over the exponents
-    for (auto exp : exponents)
-    {
+    for (auto __exp = exponents.begin(); __exp != exponents.end(); ++__exp) { auto exp = *(__exp);
       // maybe there is more effecient way to push
       // the same item multiple times to a vector?
       for(size_t i = 0, S = abs(exp.second); i < S; ++i)
@@ -2004,6 +1998,21 @@ namespace Sass {
     return false;
   }
 
+  bool Number::eq (const Expression& rhs) const
+  {
+    if (const Number* r = dynamic_cast<const Number*>(&rhs)) {
+      size_t lhs_units = numerator_units_.size() + denominator_units_.size();
+      size_t rhs_units = r->numerator_units_.size() + r->denominator_units_.size();
+      if (!lhs_units && !rhs_units) {
+        return std::fabs(value() - r->value()) < NUMBER_EPSILON;
+      }
+      return (numerator_units_ == r->numerator_units_) &&
+             (denominator_units_ == r->denominator_units_) &&
+             std::fabs(value() - r->value()) < NUMBER_EPSILON;
+    }
+    return false;
+  }
+
   bool Number::operator== (const Expression& rhs) const
   {
     if (const Number* r = dynamic_cast<const Number*>(&rhs)) {
@@ -2126,7 +2135,7 @@ namespace Sass {
   {
     if (const Map* r = dynamic_cast<const Map*>(&rhs)) {
       if (length() != r->length()) return false;
-      for (auto key : keys()) {
+      for (auto __key = keys().begin(); __key != keys().end(); ++__key) { auto key = *(__key);
         Expression* lv = at(key);
         Expression* rv = r->at(key);
         if (!rv || !lv) return false;
