@@ -152,6 +152,7 @@ namespace Sass {
     static std::string type_name() { return ""; }
     virtual bool is_false() { return false; }
     virtual bool operator== (const Expression& rhs) const { return false; }
+    virtual bool eq(const Expression& rhs) const { return *this == rhs; };
     virtual void set_delayed(bool delayed) { is_delayed(delayed); }
     virtual bool has_interpolant() const { return is_interpolant(); }
     virtual bool is_left_interpolant() const { return is_interpolant(); }
@@ -259,7 +260,7 @@ namespace Sass {
     virtual size_t hash()
     {
       if (hash_ == 0) {
-        for (T& el : elements_) {
+        for (auto __el = elements_.begin(); __el != elements_.end(); ++__el) { T& el = *(__el);
           hash_combine(hash_, el->hash());
         }
       }
@@ -289,7 +290,7 @@ namespace Sass {
   };
   struct CompareExpression {
     bool operator()(const Expression* lhs, const Expression* rhs) const {
-      return lhs && rhs && *lhs == *rhs;
+      return lhs && rhs && lhs->eq(*rhs);
     }
   };
   typedef std::unordered_map<
@@ -309,7 +310,7 @@ namespace Sass {
     virtual void adjust_after_pushing(std::pair<Expression*, Expression*> p) { }
   public:
     Hashed(size_t s = 0) : elements_(ExpressionMap(s)), list_(std::vector<Expression*>())
-    { elements_.reserve(s); list_.reserve(s); reset_duplicate_key(); }
+    { /* elements_.reserve(s); */ list_.reserve(s); reset_duplicate_key(); }
     virtual ~Hashed();
     size_t length() const                  { return list_.size(); }
     bool empty() const                     { return list_.empty(); }
@@ -338,7 +339,7 @@ namespace Sass {
         return *this;
       }
 
-      for (auto key : h->keys()) {
+      for (auto __key = h->keys().begin(); __key != h->keys().end(); ++__key) { auto key = *(__key);
         *this << std::make_pair(key, h->at(key));
       }
 
@@ -937,7 +938,7 @@ namespace Sass {
     virtual size_t hash()
     {
       if (hash_ == 0) {
-        for (auto key : keys()) {
+        for (auto __key = keys().begin(); __key != keys().end(); ++__key) { auto key = *(__key);
           hash_combine(hash_, key->hash());
           hash_combine(hash_, at(key)->hash());
         }
@@ -1230,8 +1231,7 @@ namespace Sass {
     {
       if (hash_ == 0) {
         hash_ = std::hash<std::string>()(name());
-        for (auto argument : arguments()->elements())
-          hash_combine(hash_, argument->hash());
+        for (auto __argument = arguments()->elements().begin(); __argument != arguments()->elements().end(); ++__argument) { auto argument = *(__argument); hash_combine(hash_, argument->hash()); }
       }
       return hash_;
     }
@@ -1359,16 +1359,19 @@ namespace Sass {
     {
       if (hash_ == 0) {
         hash_ = std::hash<double>()(value_);
-        for (const auto numerator : numerator_units())
+        for (auto __numerator = numerator_units().begin(); __numerator != numerator_units().end(); ++__numerator) { const auto numerator = *(__numerator);
           hash_combine(hash_, std::hash<std::string>()(numerator));
-        for (const auto denominator : denominator_units())
+        }
+        for (auto __denominator = denominator_units().begin(); __denominator != denominator_units().end(); ++__denominator) { const auto denominator = *(__denominator);
           hash_combine(hash_, std::hash<std::string>()(denominator));
+        }
       }
       return hash_;
     }
 
     virtual bool operator< (const Number& rhs) const;
     virtual bool operator== (const Expression& rhs) const;
+    virtual bool eq(const Expression& rhs) const;
 
     ATTACH_OPERATIONS()
   };
@@ -1499,7 +1502,7 @@ namespace Sass {
     bool is_right_interpolant(void) const;
     // void has_interpolants(bool tc) { }
     bool has_interpolants() {
-      for (auto el : elements()) {
+      for (auto __el = elements().begin(); __el != elements().end(); ++__el) { auto el = *(__el);
         if (el->is_interpolant()) return true;
       }
       return false;
@@ -1511,8 +1514,7 @@ namespace Sass {
     virtual size_t hash()
     {
       if (hash_ == 0) {
-        for (auto string : elements())
-          hash_combine(hash_, string->hash());
+        for (auto __string = elements().begin(); __string != elements().end(); ++__string) { auto string = *(__string); hash_combine(hash_, string->hash()); }
       }
       return hash_;
     }
@@ -2561,12 +2563,12 @@ namespace Sass {
     }
     virtual void set_media_block(Media_Block* mb) {
       media_block(mb);
-      for (Sequence_Selector* cs : elements()) {
+      for (auto __cs = elements().begin(); __cs != elements().end(); ++__cs) { Sequence_Selector* cs = *(__cs);
         cs->set_media_block(mb);
       }
     }
     virtual bool has_wrapped_selector() {
-      for (Sequence_Selector* cs : elements()) {
+      for (auto __cs = elements().begin(); __cs != elements().end(); ++__cs) { Sequence_Selector* cs = *(__cs);
         if (cs->has_wrapped_selector()) return true;
       }
       return false;
