@@ -239,7 +239,7 @@ namespace Sass {
     Expression* val = 0;
 
     if (map) {
-      for (auto key : map->keys()) {
+      for (auto __key = map->keys().begin(); __key != map->keys().end(); ++__key) { auto key = *(__key);
         Expression* value = map->at(key);
 
         if (variables.size() == 1) {
@@ -478,7 +478,7 @@ namespace Sass {
     Map* mm = SASS_MEMORY_NEW(ctx.mem, Map,
                                 m->pstate(),
                                 m->length());
-    for (auto key : m->keys()) {
+    for (auto __key = m->keys().begin(); __key != m->keys().end(); ++__key) { auto key = *(__key);
       Expression* ex_key = key->perform(this);
       Expression* ex_val = m->at(key)->perform(this);
       *mm << std::make_pair(ex_key, ex_val);
@@ -1036,7 +1036,7 @@ namespace Sass {
 
     if (Arguments* args = dynamic_cast<Arguments*>(ex)) {
       List* ll = SASS_MEMORY_NEW(ctx.mem, List, args->pstate(), 0, SASS_COMMA);
-      for(auto arg : *args) {
+      for (auto __arg = args->elements().begin(); __arg != args->elements().end(); ++__arg) { auto arg = *(__arg);
         *ll << arg->value();
       }
       ll->is_interpolant(args->is_interpolant());
@@ -1072,7 +1072,7 @@ namespace Sass {
       List* ll = SASS_MEMORY_NEW(ctx.mem, List, l->pstate(), 0, l->separator());
       // this fixes an issue with bourbon sample, not really sure why
       // if (l->size() && dynamic_cast<Null*>((*l)[0])) { res += ""; }
-      for(auto item : *l) {
+      for (auto __item = l->elements().begin(); __item != l->elements().end(); ++__item) { auto item = *(__item);
         item->is_interpolant(l->is_interpolant());
         std::string rl(""); interpolation(ctx, rl, item, into_quotes, l->is_interpolant());
         bool is_null = dynamic_cast<Null*>(item) != 0; // rl != ""
@@ -1333,11 +1333,11 @@ namespace Sass {
                                       true);
 
       if (ls && ls->is_arglist()) {
-        for (auto as : *ls) *arglist << as;
+        for (auto __as = ls->elements().begin(); __as != ls->elements().end(); ++__as) { auto as = *(__as); *arglist << as; }
       } else if (ms) {
         *aa << SASS_MEMORY_NEW(ctx.mem, Argument, splat->pstate(), ms, "", false, true);
       } else if (ls) {
-        for (auto as : *ls) *arglist << as;
+        for (auto __as = ls->elements().begin(); __as != ls->elements().end(); ++__as) { auto as = *(__as); *arglist << as; }
       } else {
         *arglist << splat;
       }
