@@ -106,10 +106,10 @@ namespace Sass {
     // do some special checks for the base level rules
     if (r->is_root()) {
       if (CommaSequence_Selector* selector_list = dynamic_cast<CommaSequence_Selector*>(r->selector())) {
-        for (Sequence_Selector* complex_selector : selector_list->elements()) {
+        for (auto __complex_selector = selector_list->elements().begin(); __complex_selector != selector_list->elements().end(); ++__complex_selector) { Sequence_Selector* complex_selector = *(__complex_selector);
           Sequence_Selector* tail = complex_selector;
           while (tail) {
-            if (tail->head()) for (Simple_Selector* header : tail->head()->elements()) {
+            if (tail->head()) for (auto __header = tail->head()->elements().begin(); __header != tail->head()->elements().end(); ++__header) { Simple_Selector* header = *(__header);
               if (dynamic_cast<Parent_Selector*>(header) == NULL) continue; // skip all others
               std::string sel_str(complex_selector->to_string(ctx.c_options));
               error("Base-level rules cannot contain the parent-selector-referencing character '&'.", header->pstate(), backtrace());
@@ -234,7 +234,7 @@ namespace Sass {
     Expression* value = d->value()->perform(&eval);
     Block* bb = ab ? ab->perform(this)->block() : 0;
     if (!bb) {
-      if (!value || (value->is_invisible() && !d->is_important())) return 0;
+    if (!value || (value->is_invisible() && !d->is_important())) return 0;
     }
     Declaration* decl = SASS_MEMORY_NEW(ctx.mem, Declaration,
                                         d->pstate(),
@@ -474,7 +474,7 @@ namespace Sass {
     Block* body = e->block();
 
     if (map) {
-      for (auto key : map->keys()) {
+      for (auto __key = map->keys().begin(); __key != map->keys().end(); ++__key) { auto key = *(__key);
         Expression* k = key->perform(&eval);
         Expression* v = map->at(key)->perform(&eval);
 
@@ -555,10 +555,10 @@ namespace Sass {
   void Expand::expand_selector_list(Selector* s, CommaSequence_Selector* extender) {
 
     if (CommaSequence_Selector* sl = dynamic_cast<CommaSequence_Selector*>(s)) {
-      for (Sequence_Selector* complex_selector : sl->elements()) {
+      for (auto __complex_selector = sl->elements().begin(); __complex_selector != sl->elements().end(); ++__complex_selector) { Sequence_Selector* complex_selector = *(__complex_selector);
         Sequence_Selector* tail = complex_selector;
         while (tail) {
-          if (tail->head()) for (Simple_Selector* header : tail->head()->elements()) {
+          if (tail->head()) for (auto __header = tail->head()->elements().begin(); __header != tail->head()->elements().end(); ++__header) { Simple_Selector* header = *(__header);
             if (dynamic_cast<Parent_Selector*>(header) == NULL) continue; // skip all others
             std::string sel_str(complex_selector->to_string(ctx.c_options));
             error("Can't extend " + sel_str + ": can't extend parent selectors", header->pstate(), backtrace());
@@ -571,7 +571,7 @@ namespace Sass {
 
     CommaSequence_Selector* contextualized = dynamic_cast<CommaSequence_Selector*>(s->perform(&eval));
     if (contextualized == NULL) return;
-    for (auto complex_sel : contextualized->elements()) {
+    for (auto __complex_sel = contextualized->elements().begin(); __complex_sel != contextualized->elements().end(); ++__complex_sel) { auto complex_sel = *(__complex_sel);
       Sequence_Selector* c = complex_sel;
       if (!c->head() || c->tail()) {
         std::string sel_str(contextualized->to_string(ctx.c_options));
@@ -611,7 +611,7 @@ namespace Sass {
         if (schema->has_parent_ref()) s = eval(schema);
       }
       if (CommaSequence_Selector* sl = dynamic_cast<CommaSequence_Selector*>(s)) {
-        for (Sequence_Selector* cs : *sl) {
+        for (auto __cs = sl->elements().begin(); __cs != sl->elements().end(); ++__cs) { Sequence_Selector* cs = *(__cs);
           if (cs != NULL && cs->head() != NULL) {
             cs->head()->media_block(media_block_stack.back());
           }
@@ -689,7 +689,7 @@ namespace Sass {
 
 
     block_stack.push_back(trace_block);
-    for (auto bb : *body) {
+    for (auto __bb = body->elements().begin(); __bb != body->elements().end(); ++__bb) { auto bb = *(__bb);
       Statement* ith = bb->perform(this);
       if (ith) *trace->block() << ith;
     }
