@@ -94,7 +94,7 @@ namespace Sass {
     return os;
   }
 
-  // Print a string representation of a SimpleSequence_Selector
+  // Print a string representation of a Compound_Selector
   static void printSimpleSelector(Simple_Selector* pSimpleSelector, const char* message=NULL, bool newline=true) {
 
     if (message) {
@@ -112,12 +112,12 @@ namespace Sass {
     }
   }
 
-  // Print a string representation of a SimpleSequence_Selector
+  // Print a string representation of a Compound_Selector
     typedef std::pair<SimpleSequence_Selector*, Sequence_Selector*> SelsNewSeqPair;
     typedef std::vector<SelsNewSeqPair> SelsNewSeqPairCollection;
 
 
-  // Print a string representation of a SimpleSequence_Selector
+  // Print a string representation of a Compound_Selector
   static void printCompoundSelector(SimpleSequence_Selector* pCompoundSelector, const char* message=NULL, bool newline=true) {
 
     if (message) {
@@ -169,7 +169,7 @@ namespace Sass {
   }
 
 
-  // Print a string representation of a Sequence_Selector
+  // Print a string representation of a Complex_Selector
   static void printComplexSelector(Sequence_Selector* pComplexSelector, const char* message=NULL, bool newline=true) {
 
     if (message) {
@@ -194,7 +194,7 @@ namespace Sass {
     }
     bool first = true;
     std::cerr << "[";
-    for(SelsNewSeqPair& pair : collection) {
+    for (auto __pair = collection.begin(); __pair != collection.end(); ++__pair) { SelsNewSeqPair& pair = *(__pair);
       if (first) {
         first = false;
       } else {
@@ -288,7 +288,7 @@ namespace Sass {
 #endif
 
   static bool parentSuperselector(Sequence_Selector* pOne, Sequence_Selector* pTwo, Context& ctx) {
-    // TODO: figure out a better way to create a Sequence_Selector from scratch
+    // TODO: figure out a better way to create a Complex_Selector from scratch
     // TODO: There's got to be a better way. This got ugly quick...
     Position noPosition(-1, -1, -1);
     Element_Selector fakeParent(ParserState("[FAKE]"), "temp");
@@ -651,7 +651,7 @@ namespace Sass {
 
 
   static bool parentSuperselector(const Node& one, const Node& two, Context& ctx) {
-    // TODO: figure out a better way to create a Sequence_Selector from scratch
+    // TODO: figure out a better way to create a Complex_Selector from scratch
     // TODO: There's got to be a better way. This got ugly quick...
     Position noPosition(-1, -1, -1);
     Element_Selector fakeParent(ParserState("[FAKE]"), "temp");
@@ -1588,7 +1588,7 @@ namespace Sass {
       Sequence_Selector* pExtComplexSelector = &seq;    // The selector up to where the @extend is (ie, the thing to merge)
       SimpleSequence_Selector* pExtCompoundSelector = pSels; // All the simple selectors to be replaced from the current compound selector from all extensions
 
-      // TODO: This can return a SimpleSequence_Selector with no elements. Should that just be returning NULL?
+      // TODO: This can return a Compound_Selector with no elements. Should that just be returning NULL?
       // RUBY: self_without_sel = Sass::Util.array_minus(members, sels)
       SimpleSequence_Selector* pSelectorWithoutExtendSelectors = pSelector->minus(pExtCompoundSelector, ctx);
 
@@ -1618,8 +1618,8 @@ namespace Sass {
       // next if group.map {|e, _| check_directives_match!(e, parent_directives)}.none?
 
       // TODO: This seems a little fishy to me. See if it causes any problems. From the ruby, we should be able to just
-      // get rid of the last SimpleSequence_Selector and replace it with this one. I think the reason this code is more
-      // complex is that Sequence_Selector contains a combinator, but in ruby combinators have already been filtered
+      // get rid of the last Compound_Selector and replace it with this one. I think the reason this code is more
+      // complex is that Complex_Selector contains a combinator, but in ruby combinators have already been filtered
       // out and aren't operated on.
       Sequence_Selector* pNewSelector = pExtComplexSelector->cloneFully(ctx); // ->first();
 
@@ -1642,7 +1642,7 @@ namespace Sass {
 
 
       // if (pSelector && pSelector->has_line_feed()) pNewInnerMost->has_line_feed(true);
-      // Set the sources on our new Sequence_Selector to the sources of this simple sequence plus the thing we're extending.
+      // Set the sources on our new Complex_Selector to the sources of this simple sequence plus the thing we're extending.
       DEBUG_PRINTLN(EXTEND_COMPOUND, "SOURCES SETTING ON NEW SEQ: " << complexSelectorToNode(pNewSelector, ctx))
 
       DEBUG_EXEC(EXTEND_COMPOUND, SourcesSet oldSet = pNewSelector->sources(); printSourcesSet(oldSet, ctx, "SOURCES NEW SEQ BEGIN: "))
@@ -1723,10 +1723,10 @@ namespace Sass {
 
       if (pHead) {
         if (seen.find(*pHead) == seen.end()) {
-          for (Simple_Selector* pSimple : *pHead) {
+          for (auto __pSimple = pHead->elements().begin(); __pSimple != pHead->elements().end(); ++__pSimple) { Simple_Selector* pSimple = *(__pSimple);
             if (Wrapped_Selector* ws = dynamic_cast<Wrapped_Selector*>(pSimple)) {
               if (CommaSequence_Selector* sl = dynamic_cast<CommaSequence_Selector*>(ws->selector())) {
-                for (Sequence_Selector* cs : sl->elements()) {
+                for (auto __cs = sl->elements().begin(); __cs != sl->elements().end(); ++__cs) { Sequence_Selector* cs = *(__cs);
                   while (cs) {
                     if (complexSelectorHasExtension(cs, ctx, subset_map, seen)) {
                       hasExtension = true;
@@ -1740,7 +1740,7 @@ namespace Sass {
           }
         }
         SubsetMapEntries entries = subset_map.get_v(pHead->to_str_vec());
-        for (ExtensionPair ext : entries) {
+        for (auto __ext = entries.begin(); __ext != entries.end(); ++__ext) { ExtensionPair ext = *(__ext);
           // check if both selectors have the same media block parent
           // if (ext.first->media_block() == pComplexSelector->media_block()) continue;
           if (ext.second->media_block() == 0) continue;
@@ -1809,7 +1809,7 @@ namespace Sass {
       // RUBY: next [[sseq_or_op]] unless sseq_or_op.is_a?(SimpleSequence)
       if (!sseqOrOp.isSelector()) {
         // Wrap our Combinator in two collections to match ruby. This is essentially making a collection Node
-        // with one collection child. The collection child represents a Sequence_Selector that is only a combinator.
+        // with one collection child. The collection child represents a Complex_Selector that is only a combinator.
         Node outer = Node::createCollection();
         Node inner = Node::createCollection();
         outer.collection()->push_back(inner);
@@ -1826,7 +1826,7 @@ namespace Sass {
       DEBUG_PRINTLN(EXTEND_COMPLEX, "EXTENDED: " << extended)
 
 
-      // Prepend the SimpleSequence_Selector based on the choices logic; choices seems to be extend but with an ruby Array instead of a Sequence
+      // Prepend the Compound_Selector based on the choices logic; choices seems to be extend but with an ruby Array instead of a Sequence
       // due to the member mapping: choices = extended.map {|seq| seq.members}
       Sequence_Selector* pJustCurrentCompoundSelector = sseqOrOp.selector();
 
@@ -1961,7 +1961,7 @@ namespace Sass {
     pNewSelectors = remove_placeholders.remove_placeholders(pNewSelectors);
 
     // unwrap all wrapped selectors with inner lists
-    for (Sequence_Selector* cur : *pNewSelectors) {
+    for (auto __cur = pNewSelectors->elements().begin(); __cur != pNewSelectors->elements().end(); ++__cur) { Sequence_Selector* cur = *(__cur);
       // process tails
       while (cur) {
         // process header
@@ -1970,7 +1970,7 @@ namespace Sass {
           recseen.insert(*cur->head());
           // create a copy since we add multiple items if stuff get unwrapped
           SimpleSequence_Selector* cpy_head = SASS_MEMORY_NEW(ctx.mem, SimpleSequence_Selector, cur->pstate());
-          for (Simple_Selector* hs : *cur->head()) {
+          for (auto __hs = cur->head()->elements().begin(); __hs != cur->head()->elements().end(); ++__hs) { Simple_Selector* hs = *(__hs);
             if (Wrapped_Selector* ws = dynamic_cast<Wrapped_Selector*>(hs)) {
               if (CommaSequence_Selector* sl = dynamic_cast<CommaSequence_Selector*>(ws->selector())) {
                 // special case for ruby ass
@@ -2092,7 +2092,8 @@ namespace Sass {
     // we set `extended` flag on extended selectors
     if (b->is_root()) {
       // debug_subset_map(subset_map);
-      for(auto const &it : subset_map.values()) {
+      auto values = subset_map.values();
+      for (auto __it = values.begin(); __it != values.end(); ++__it) { auto it = *(__it);
         Sequence_Selector* sel = it.first ? it.first->first() : NULL;
         SimpleSequence_Selector* ext = it.second ? it.second : NULL;
         if (ext && (ext->extended() || ext->is_optional())) continue;
@@ -2127,7 +2128,7 @@ namespace Sass {
 
   void Extend::operator()(Directive* a)
   {
-    // CommaSequence_Selector* ls = dynamic_cast<CommaSequence_Selector*>(a->selector());
+    // Selector_List* ls = dynamic_cast<Selector_List*>(a->selector());
     // selector_stack.push_back(ls);
     if (a->block()) a->block()->perform(this);
     // exp.selector_stack.pop_back();
