@@ -303,7 +303,7 @@ namespace Sass {
     do {
       while (lex< block_comment >());
       if (lex< quoted_string >()) {
-        to_import.push_back(std::pair<std::string,Function_Call*>(std::string(lexed), 0));
+        to_import.push_back(std::pair<std::string,Function_Call*>(std::string(lexed), (Function_Call*)0));
       }
       else if (lex< uri_prefix >()) {
         Arguments* args = SASS_MEMORY_NEW(ctx.mem, Arguments, pstate);
@@ -338,7 +338,7 @@ namespace Sass {
       imp->media_queries(media_queries);
     }
 
-    for(auto location : to_import) {
+    for (auto __location = to_import.begin(); __location != to_import.end(); ++__location) { auto location = *(__location);
       if (location.second) {
         imp->urls().push_back(location.second);
       } else if (!ctx.call_importers(unquote(location.first), path, pstate, imp)) {
