@@ -79,18 +79,6 @@ BANNER
         options[:precision] = precision
       end
 
-      opts.on("--expect-failure IMPLEMENTATION",
-              "Expect implementation to fail for the specified tests.") do |impl|
-        return unless assert_not_file!(impl, "implementation for --expect-failure")
-        (options[:add_expect_failure] ||= Set.new) << impl
-      end
-
-      opts.on("--expect-pass IMPLEMENTATION",
-              "Expect implementation to pass for the specified tests.") do |impl|
-        return unless assert_not_file!(impl, "implementation for --expect-pass")
-        (options[:remove_expect_failure] ||= Set.new) << impl
-      end
-
       opts.on("--pending IMPLEMENTATION",
               "Mark implementation as not having implemented the tests.") do |impl|
         return unless assert_not_file!(impl, "implementation for --pending")
@@ -103,6 +91,42 @@ BANNER
         (options[:remove_todo] ||= Set.new) << impl
       end
 
+      opts.on("--pending-warning IMPLEMENTATION",
+              "Mark implementation as not having implemented the warnings issued by the tests.") do |impl|
+        return unless assert_not_file!(impl, "implementation for --pending")
+        (options[:add_warning_todo] ||= Set.new) << impl
+      end
+
+      opts.on("--activate-warning IMPLEMENTATION",
+              "Mark implementation as having implemented the warnings issued by the tests.") do |impl|
+        return unless assert_not_file!(impl, "implementation for --activate")
+        (options[:remove_warning_todo] ||= Set.new) << impl
+      end
+
+      opts.on("--ignore-for IMPLEMENTATION",
+              "Flag test so that it won't run against the specified implementation.") do |impl|
+        return unless assert_not_file!(impl, "implementation for --ignore-for")
+        (options[:add_ignore_for] ||= Set.new) << impl
+      end
+
+      opts.on("--unignore-for IMPLEMENTATION",
+              "Remove the ignore flag so that the test will run against the specified implementation.") do |impl|
+        return unless assert_not_file!(impl, "implementation for --unignore-for")
+        (options[:remove_ignore_for] ||= Set.new) << impl
+      end
+
+      opts.on("--ignore-warning-for IMPLEMENTATION",
+              "Flag test so that it won't check warnings with the specified implementation.") do |impl|
+        return unless assert_not_file!(impl, "implementation for --ignore-warning-for")
+        (options[:add_ignore_warning_for] ||= Set.new) << impl
+      end
+
+      opts.on("--unignore-warning-for IMPLEMENTATION",
+              "Remove the ignore flag so that warnings are checked with the specified implementation.") do |impl|
+        return unless assert_not_file!(impl, "implementation for --unignore-warning-for")
+        (options[:remove_ignore_warning_for] ||= Set.new) << impl
+      end
+
       opts.on("--report", "Generate a report after running.") do |impl|
         runner_options[:report] = true
       end
@@ -208,7 +232,7 @@ BANNER
     column(metadata.name)
     SassSpec::LANGUAGE_VERSIONS.each do |version|
       v = Gem::Version.new(version)
-      if metadata.valid_for_version(v)
+      if metadata.valid_for_version?(v)
         column("✓")
       else
         column("")
