@@ -1,4 +1,5 @@
 require 'minitest'
+require 'thread'
 require 'fileutils'
 require 'yaml'
 require_relative "interactor"
@@ -19,12 +20,15 @@ def run_spec_test(test_case, options = {})
     return true
   end
 
-  return unless handle_missing_output!(test_case)
+  return unless check_annotations!(test_case, options)
+  return unless handle_missing_output!(test_case, options)
   return unless handle_unexpected_error!(test_case, options)
   return unless handle_unexpected_pass!(test_case, options)
   return unless handle_output_difference!(test_case, options)
 
-  if test_case.warning_todo? && !options[:run_todo]
+  if test_case.ignore_warning?
+    return true
+  elsif test_case.warning_todo? && !options[:run_todo]
     skip "Skipped warning check for #{test_case.folder}"
   else
     return unless handle_expected_error_message!(test_case, options)
@@ -34,16 +38,30 @@ def run_spec_test(test_case, options = {})
   return true
 end
 
+$interaction_memory = {}
+
 # if the test case is interactive it will do the interaction and return
 # the choice. Otherwise, it returns the default.
-def interact(test_case, default, &block)
+def interact(test_case, prompt_id, default, &block)
   if test_case.interactive?
-    return SassSpec::Interactor.interact(&block)
+    relative_path = Pathname.new(test_case.folder).relative_path_from(Pathname.new(Dir.pwd))
+    print "\nIn test case: #{relative_path}"
+    return SassSpec::Interactor.interact_with_memory($interaction_memory, prompt_id, &block)
   else
     return default
   end
 end
 
+def skip_test_case!(test_case, reason = nil)
+  msg = "Skipped #{test_case.folder}" 
+  if reason
+    msg << ": #{reason}"
+  else
+    msg << "."
+  end
+  skip msg
+end
+
 def handle_expected_error_message!(test_case, options)
   return true unless test_case.verify_stderr?
 
@@ -53,8 +71,9 @@ def handle_expected_error_message!(test_case, options)
   expected_error_msg = _extract_error_message(test_case.expected_error, options)
 
   if expected_error_msg != error_msg
-    return false if test_case.probe_todo?
-    interact(test_case, :fail) do |i|
+    skip_test_case!(test_case, "TODO test is failing") if test_case.probe_todo?
+
+    interact(test_case, :expected_error_different, :fail) do |i|
       i.prompt(error_msg.nil? ? "An error message was expected but wasn't produced." :
                                 "Error output doesn't match what was expected.")
 
@@ -93,6 +112,11 @@ def handle_expected_error_message!(test_case, options)
         return false
       end
 
+      i.choice(:ignore, "Ignore warning for #{test_case.impl}.") do
+        change_options(test_case.options_path, add_ignore_warning_for: [test_case.impl])
+        return false
+      end
+
       i.choice(:fail, "Mark as failed.")
 
       i.choice(:exit, "Exit testing.") do
@@ -116,8 +140,9 @@ def handle_unexpected_error_message!(test_case, options)
 
   return true if error_msg.nil? || error_msg.length == 0
 
-  return false if test_case.probe_todo?
-  interact(test_case, :fail) do |i|
+  skip_test_case!(test_case, "TODO test is failing")  if test_case.probe_todo?
+
+  interact(test_case, :unexpected_error_message, :fail) do |i|
     i.prompt "Unexpected output to stderr"
 
     i.choice(:show_source, "Show me the input.") do
@@ -145,6 +170,11 @@ def handle_unexpected_error_message!(test_case, options)
       return false
     end
 
+    i.choice(:ignore, "Ignore warning for #{test_case.impl}.") do
+      change_options(test_case.options_path, add_ignore_warning_for: [test_case.impl])
+      return false
+    end
+
     i.choice(:fail, "Mark as failed.")
 
     i.choice(:exit, "Exit testing.") do
@@ -164,8 +194,9 @@ def handle_output_difference!(test_case, options)
     return false
   end
 
-  return false if test_case.probe_todo?
-  interact(test_case, :fail) do |i|
+  skip_test_case!(test_case, "TODO test is failing") if test_case.probe_todo?
+
+  interact(test_case, :output_difference, :fail) do |i|
     i.prompt "output does not match expectation"
 
     i.choice(:show_source, "Show me the input.") do
@@ -191,6 +222,11 @@ def handle_output_difference!(test_case, options)
       return false
     end
 
+    i.choice(:ignore, "Ignore test for #{test_case.impl} FOREVER.") do
+      change_options(test_case.options_path, add_ignore_for: [test_case.impl])
+      return false
+    end
+
     i.choice(:fail, "Mark as failed.")
 
     i.choice(:exit, "Exit testing.") do
@@ -202,14 +238,72 @@ def handle_output_difference!(test_case, options)
   return true
 end
 
-def handle_missing_output!(test_case)
+$sources = {}
+$sources_mutex = Mutex.new
+
+def check_annotations!(test_case, options)
+  return true unless options[:check_annotations]
+
+  _output, _, error, _ = test_case.output
+  ignored_warning_impls = test_case.metadata.warnings_ignored_for
+
+
+  # $sources_mutex.synchronize do
+  #   if $sources[test_case.input]
+  #     $sources[test_case.input].each do |folder|
+  #       tc = SassSpec::TestCase.new(folder, options)
+  #       if test_case.equivalent?(tc)
+  #         message = "Test case appears to be equivalent to: #{folder}"
+  #         assert false, message
+  #       end
+  #     end
+  #   end
+  #   ($sources[test_case.input] ||= []) << test_case.folder
+  # end
+
+  if ignored_warning_impls.any? && error.length == 0
+    message = "No warning issued, but warnings are ignored for #{ignored_warning_impls.join(', ')}"
+    choice = interact(test_case, :ignore_warning_nonexistant, :fail) do |i|
+      i.prompt message
+      i.choice(:remove_ignore, "Remove ignored status for #{ignored_warning_impls.join(', ')}") do
+        change_options(test_case.options_path, remove_ignore_warning_for: ignored_warning_impls)
+      end
+      i.choice(:fail, "Mark as failed.")
+    end
+
+    if (choice == :fail)
+      assert false, message
+    end
+  end
+
+  todo_warning_impls = test_case.metadata.all_warning_todos
+  if todo_warning_impls.any? && error.length == 0
+    message = "No warning issued, but warnings are pending for #{todo_warning_impls.join(', ')}"
+    choice = interact(test_case, :todo_warning_nonexistant, :fail) do |i|
+      i.prompt message
+      i.choice(:remove_ignore, "Remove TODO status for #{todo_warning_impls.join(', ')}") do
+        change_options(test_case.options_path, remove_warning_todo: todo_warning_impls)
+      end
+      i.choice(:fail, "Mark as failed.")
+    end
+
+    if (choice == :fail)
+      assert false, message
+    end
+  end
+
+  return true
+end
+
+def handle_missing_output!(test_case, options)
   return true if File.exists?(test_case.expected_path)
 
   output, _, error, _ = test_case.output
-  return false if test_case.probe_todo?
-  choice = interact(test_case, :fail) do |i|
-    i.prompt "in #{test_case.name}\n" +
-             "Expected output file does not exist."
+
+  skip_test_case!(test_case, "TODO test is failing") if test_case.probe_todo?
+
+  choice = interact(test_case, :missing_output, :fail) do |i|
+    i.prompt "Expected output file does not exist."
 
     i.choice(:show_source, "Show me the input.") do
       display_text_block(File.read(test_case.input_path))
@@ -250,7 +344,7 @@ def handle_missing_output!(test_case)
 end
 
 def handle_unexpected_pass!(test_case, options)
-  output, _clean_output, error, status = test_case.output
+  output, _clean_output, _error, status = test_case.output
   if status == 0
     return true if !test_case.should_fail?
 
@@ -260,9 +354,8 @@ def handle_unexpected_pass!(test_case, options)
     end
 
     return false if test_case.probe_todo?
-    choice = interact(test_case, :fail) do |i|
-      i.prompt "In #{test_case.name}\n" +
-               "A failure was expected but it compiled instead."
+    choice = interact(test_case, :unexpected_pass, :fail) do |i|
+      i.prompt "A failure was expected but it compiled instead."
       i.choice(:show_source, "Show me the input.") do
         display_text_block(File.read(test_case.input_path))
         i.restart!
@@ -286,6 +379,10 @@ def handle_unexpected_pass!(test_case, options)
         migrate_test!(test_case, options) || i.restart!
       end
 
+      i.choice(:ignore, "Ignore test for #{test_case.impl} FOREVER.") do
+        change_options(test_case.options_path, add_ignore_for: [test_case.impl])
+      end
+
       i.choice(:fail, "Fail test and continue.")
 
       i.choice(:exit, "Exit testing.") do
@@ -309,10 +406,10 @@ def handle_unexpected_error!(test_case, options)
       return false
     end
 
-    return false if test_case.probe_todo?
-    choice = interact(test_case, :fail) do |i|
-      i.prompt "In #{test_case.name}\n" +
-               "An unexpected compiler error was encountered."
+    skip_test_case!(test_case, "TODO test is failing") if test_case.probe_todo?
+
+    choice = interact(test_case, :unexpected_error, :fail) do |i|
+      i.prompt "An unexpected compiler error was encountered."
       i.choice(:show_source, "Show me the input.") do
         display_text_block(File.read(test_case.input_path))
         i.restart!
@@ -336,6 +433,10 @@ def handle_unexpected_error!(test_case, options)
         migrate_test!(test_case, options) || i.restart!
       end
 
+      i.choice(:ignore, "Ignore test for #{test_case.impl} FOREVER.") do
+        change_options(test_case.options_path, add_ignore_for: [test_case.impl])
+      end
+
       i.choice(:fail, "Fail test and continue.")
 
       i.choice(:exit, "Exit testing.") do
@@ -351,7 +452,7 @@ end
 
 def delete_test!(test_case)
   files = Dir.glob(File.join(test_case.folder, "**", "*"))
-  result = interact(test_case, :proceed) do |i|
+  result = interact(test_case, :delete_test, :proceed) do |i|
     i.prompt("The following files will be removed:\n  * " + files.join("\n  * "))
     i.choice(:proceed, "Delete them.") do
       FileUtils.rm_rf(test_case.folder)
@@ -421,7 +522,7 @@ def migrate_test!(test_case, options)
   new_folder = test_case.folder + "-#{current_version}"
 
   if File.exist?(new_folder)
-    choice = interact(test_case, :abort) do |i|
+    choice = interact(test_case, :migrate_over_existing, :abort) do |i|
       i.prompt("Target folder '#{new_folder}' already exists.")
       i.choice(:abort, "Don't migrate the test.") do
         return false
@@ -471,6 +572,7 @@ def change_options(options_file, options)
 
 end
 
+
 GEMFILE_PREFIX_LENGTH = 68
 # When running sass-spec as a gem from github very long filenames
 # can cause installation issues. This checks that the paths in use will work.
@@ -501,40 +603,30 @@ def assert_filename_length!(filename, options)
 end
 
 def _extract_error_message(error, options)
-  skip = false
-  error.each_line do |error_line|
-    if (error_line =~ /DEPRECATION WARNING/)
-      skip = false
+  error_message = ""
+  consume_next_line = false
+  error.each_line do |line|
+    if consume_next_line
+      next if line.strip == ""
+      error_message += line
+      break
     end
-    if (error_line =~ /Error:/)
-      skip = false
+    if (line =~ /DEPRECATION WARNING/)
+      if line.rstrip.end_with?(":")
+        error_message = line.rstrip + "\n"
+        consume_next_line = true
+        next
+      else
+        error_message = line
+        break
+      end
     end
-    # disable once we support this deprecation fully
-    if (error_line =~ /interpolation near operators will be simplified/)
-      skip = true
-      next
+    if (line =~ /Error:/)
+      error_message = line
+      break
     end
-    # disable once we support this deprecation fully
-    # if (error_line =~ /The subject selector operator \"!\" is deprecated and will be removed/)
-    #   skip = true
-    #   next
-    # end
-    # disable once we support this deprecation fully
-    if (error_line =~ /Passing a percentage as the alpha/)
-      skip = true
-      next
-    end
-    # disable once we support this deprecation fully (partial now)
-    # if (error_line =~ /, a non-string value, to unquote()/)
-    #   skip = true
-    #   next
-    # end
-    if (skip)
-      next
-    end
-    return _clean_debug_path(error_line.rstrip, options[:spec_directory])
   end
-  return nil
+  _clean_debug_path(error_message.rstrip, options[:spec_directory])
 end
 
 def _clean_debug_path(error, spec_dir)
