@@ -68,10 +68,6 @@ class SassSpec::TestCase
     @error_path
   end
 
-  def verify_stderr?
-    @verify_stderr
-  end
-
   def status_path
     @status_path
   end
@@ -80,6 +76,10 @@ class SassSpec::TestCase
     @options_path
   end
 
+  def verify_stderr?
+    @verify_stderr
+  end
+
   def interactive?
     @options[:interactive]
   end
@@ -109,12 +109,20 @@ class SassSpec::TestCase
     @metadata.warning_todo?(impl)
   end
 
+  def ignore?
+    @metadata.ignore_for?(impl)
+  end
+
+  def ignore_warning?
+    @metadata.ignore_warning_for?(impl)
+  end
+
   def metadata
     @metadata
   end
 
   def overwrite?
-    @options[:generate] || @options[:nuke]
+    @options[:generate]
   end
 
   def output
@@ -122,7 +130,7 @@ class SassSpec::TestCase
       return @output
     end
 
-    stdout, stderr, status = engine.compile(@input_path, output_style, precision)
+    stdout, stderr, status = engine.compile(input_path, output_style, precision)
 
     if clean_test
       clean_out = _clean_output(stdout)
@@ -138,6 +146,10 @@ class SassSpec::TestCase
     @output ||= [stdout, clean_out, stderr, status]
   end
 
+  def input
+    @input ||= File.read(input_path, :binmode => true, :encoding => "ASCII-8BIT")
+  end
+
   def expected
     output = File.read(@expected_path, :binmode => true, :encoding => "ASCII-8BIT")
     # we seem to get CP850 otherwise
@@ -151,7 +163,16 @@ class SassSpec::TestCase
   end
 
   def expected_error
-    @expected_error = _clean_error((File.read(@error_path, :binmode => true, :encoding => "ASCII-8BIT") rescue ""))
+    @expected_error ||= if File.file?(@error_path)
+                          _clean_error(File.read(@error_path, :binmode => true,
+                                                 :encoding => "ASCII-8BIT"))
+                        else
+                          ""
+                        end
+  end
+
+  def equivalent?(other_test_case)
+    output == other_test_case.output
   end
 
   def expected_status
